@@ -254,7 +254,12 @@ except ImportError as exp:
                     raise_parse_error(node, 'Requires sequence of float values')
             return values
         def gds_format_decimal(self, input_data, input_name=''):
-            return ('%s' % input_data).rstrip('0')
+            return_value = '%s' % input_data
+            if '.' in return_value:
+                return_value = return_value.rstrip('0')
+                if return_value.endswith('.'):
+                    return_value = return_value.rstrip('.')
+            return return_value
         def gds_parse_decimal(self, input_data, node=None, input_name=''):
             try:
                 decimal_value = decimal_.Decimal(input_data)
@@ -268,7 +273,7 @@ except ImportError as exp:
                 raise_parse_error(node, 'Requires decimal value')
             return value
         def gds_format_decimal_list(self, input_data, input_name=''):
-            return '%s' % ' '.join(input_data)
+            return ' '.join([self.gds_format_decimal(item) for item in input_data])
         def gds_validate_decimal_list(
                 self, input_data, node=None, input_name=''):
             values = input_data.split()
@@ -966,89 +971,89 @@ class oneperEnumType01_1(Enum):
     TOKEN='token'
 
 
-class oneperType01_1(GeneratedsSuper):
+class oneperType02_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('username', 'xs:string', 0, 0, {'name': 'username', 'type': 'xs:string'}, None),
-        MemberSpec_('inner01', 'oneperType01_2', 0, 0, {'name': 'inner01', 'type': 'oneperType01_2'}, None),
+        MemberSpec_('clientname', 'xs:string', 0, 0, {'name': 'clientname', 'type': 'xs:string'}, None),
+        MemberSpec_('inner01', 'oneperType02_2', 0, 0, {'name': 'inner01', 'type': 'oneperType02_2'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, username=None, inner01=None, gds_collector_=None, **kwargs_):
+    def __init__(self, clientname=None, inner01=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.username = username
-        self.username_nsprefix_ = None
+        self.clientname = clientname
+        self.clientname_nsprefix_ = None
         self.inner01 = inner01
         self.inner01_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType01_1)
+                CurrentSubclassModule_, oneperType02_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType01_1.subclass:
-            return oneperType01_1.subclass(*args_, **kwargs_)
+        if oneperType02_1.subclass:
+            return oneperType02_1.subclass(*args_, **kwargs_)
         else:
-            return oneperType01_1(*args_, **kwargs_)
+            return oneperType02_1(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_username(self):
-        return self.username
-    def set_username(self, username):
-        self.username = username
+    def get_clientname(self):
+        return self.clientname
+    def set_clientname(self, clientname):
+        self.clientname = clientname
     def get_inner01(self):
         return self.inner01
     def set_inner01(self, inner01):
         self.inner01 = inner01
     def hasContent_(self):
         if (
-            self.username is not None or
+            self.clientname is not None or
             self.inner01 is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType01_1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_1', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType02_1')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType01_1':
+        if self.original_tagname_ is not None and name_ == 'oneperType02_1':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_1')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType02_1')
         if self.hasContent_():
             outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_1', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType02_1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType01_1'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType02_1'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_1', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_1', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.username is not None:
-            namespaceprefix_ = self.username_nsprefix_ + ':' if (UseCapturedNS_ and self.username_nsprefix_) else ''
+        if self.clientname is not None:
+            namespaceprefix_ = self.clientname_nsprefix_ + ':' if (UseCapturedNS_ and self.clientname_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%susername>%s</%susername>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.username), input_name='username')), namespaceprefix_ , eol_))
+            outfile.write('<%sclientname>%s</%sclientname>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.clientname), input_name='clientname')), namespaceprefix_ , eol_))
         if self.inner01 is not None:
             namespaceprefix_ = self.inner01_nsprefix_ + ':' if (UseCapturedNS_ and self.inner01_nsprefix_) else ''
             self.inner01.export(outfile, level, namespaceprefix_, namespacedef_='', name_='inner01', pretty_print=pretty_print)
@@ -1066,95 +1071,95 @@ class oneperType01_1(GeneratedsSuper):
     def buildAttributes(self, node, attrs, already_processed):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'username':
+        if nodeName_ == 'clientname':
             value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'username')
-            value_ = self.gds_validate_string(value_, node, 'username')
-            self.username = value_
-            self.username_nsprefix_ = child_.prefix
+            value_ = self.gds_parse_string(value_, node, 'clientname')
+            value_ = self.gds_validate_string(value_, node, 'clientname')
+            self.clientname = value_
+            self.clientname_nsprefix_ = child_.prefix
         elif nodeName_ == 'inner01':
-            obj_ = oneperType01_2.factory(parent_object_=self)
+            obj_ = oneperType02_2.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.inner01 = obj_
             obj_.original_tagname_ = 'inner01'
-# end class oneperType01_1
+# end class oneperType02_1
 
 
-class oneperType01_2(GeneratedsSuper):
+class oneperType02_2(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('userdescription', 'xs:string', 0, 0, {'name': 'userdescription', 'type': 'xs:string'}, None),
+        MemberSpec_('clientdescription', 'xs:string', 0, 0, {'name': 'clientdescription', 'type': 'xs:string'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, userdescription=None, gds_collector_=None, **kwargs_):
+    def __init__(self, clientdescription=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.userdescription = userdescription
-        self.userdescription_nsprefix_ = None
+        self.clientdescription = clientdescription
+        self.clientdescription_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType01_2)
+                CurrentSubclassModule_, oneperType02_2)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType01_2.subclass:
-            return oneperType01_2.subclass(*args_, **kwargs_)
+        if oneperType02_2.subclass:
+            return oneperType02_2.subclass(*args_, **kwargs_)
         else:
-            return oneperType01_2(*args_, **kwargs_)
+            return oneperType02_2(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_userdescription(self):
-        return self.userdescription
-    def set_userdescription(self, userdescription):
-        self.userdescription = userdescription
+    def get_clientdescription(self):
+        return self.clientdescription
+    def set_clientdescription(self, clientdescription):
+        self.clientdescription = clientdescription
     def hasContent_(self):
         if (
-            self.userdescription is not None
+            self.clientdescription is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_2', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType01_2')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_2', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType02_2')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType01_2':
+        if self.original_tagname_ is not None and name_ == 'oneperType02_2':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_2')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType02_2')
         if self.hasContent_():
             outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_2', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType02_2', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType01_2'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType02_2'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_2', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType02_2', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.userdescription is not None:
-            namespaceprefix_ = self.userdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.userdescription_nsprefix_) else ''
+        if self.clientdescription is not None:
+            namespaceprefix_ = self.clientdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.clientdescription_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%suserdescription>%s</%suserdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.userdescription), input_name='userdescription')), namespaceprefix_ , eol_))
+            outfile.write('<%sclientdescription>%s</%sclientdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.clientdescription), input_name='clientdescription')), namespaceprefix_ , eol_))
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1169,17 +1174,17 @@ class oneperType01_2(GeneratedsSuper):
     def buildAttributes(self, node, attrs, already_processed):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'userdescription':
+        if nodeName_ == 'clientdescription':
             value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'userdescription')
-            value_ = self.gds_validate_string(value_, node, 'userdescription')
-            self.userdescription = value_
-            self.userdescription_nsprefix_ = child_.prefix
-# end class oneperType01_2
+            value_ = self.gds_parse_string(value_, node, 'clientdescription')
+            value_ = self.gds_validate_string(value_, node, 'clientdescription')
+            self.clientdescription = value_
+            self.clientdescription_nsprefix_ = child_.prefix
+# end class oneperType02_2
 
 
 GDSClassesMapping = {
-    'root01': oneperType01_1,
+    'root02': oneperType02_1,
 }
 
 
@@ -1226,8 +1231,8 @@ def parse(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     CapturedNsmap_, namespacedefs = get_required_ns_prefix_defs(rootNode)
@@ -1258,8 +1263,8 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1301,8 +1306,8 @@ def parseString(inString, silence=False, print_warnings=True):
     gds_collector = GdsCollector_()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if not SaveElementTreeNode:
@@ -1329,8 +1334,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType01_1'
-        rootClass = oneperType01_1
+        rootTag = 'oneperType02_1'
+        rootClass = oneperType02_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1338,8 +1343,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
         doc = None
         rootNode = None
 ##     if not silence:
-##         sys.stdout.write('#from oneperType01_1One import *\n\n')
-##         sys.stdout.write('import oneperType01_1One as model_\n\n')
+##         sys.stdout.write('#from oneperType02_1One import *\n\n')
+##         sys.stdout.write('import oneperType02_1One as model_\n\n')
 ##         sys.stdout.write('rootObj = model_.rootClass(\n')
 ##         rootObj.exportLiteral(sys.stdout, 0, name_=rootTag)
 ##         sys.stdout.write(')\n')
@@ -1369,6 +1374,6 @@ RenameMappings_ = {
 
 }
 __all__ = [
-    "oneperType01_1",
-    "oneperType01_2"
+    "oneperType02_1",
+    "oneperType02_2"
 ]
